request_screen_recording_permission

Function request_screen_recording_permission 

pub async fn request_screen_recording_permission() -> CameraPermission
Proactively trigger the Screen Recording TCC request.

This is intentionally separate from screen_recording_permission_status: status is a side-effect-free preflight, while this function is what causes macOS to show the Screen & System Audio Recording consent sheet and add the current app identity to the Settings list.